
RELEASE_VERSION='0.3.651814076'
BUILD_DATE='Tue Sep 27 12:20:04 UTC 2022'
BUILD_MACHINE_INFO='Linux runner--rvkxsvp-project-28359933-concurrent-0kzcrz 5.4.209-116.363.amzn2.x86_64 #1 SMP Wed Aug 10 21:19:18 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='3090821872'
GIT_COMMIT_SHA='f1d40411694fee79a0adeed7e81a4818f1bff6a0'
GIT_BRANCH='main'
